/**
 * Modified by Max Hailperin <max@gustavus.edu> from 
 *   javaee-tutorial/examples/jms/simple/producer/src/main/java/
 *   javaeetutorial/producer/Producer.java
 * which had the following notice:
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * You may not modify, use, reproduce, or distribute this software except in
 * compliance with  the terms of the License at:
 * http://java.net/projects/javaeetutorial/pages/BerkeleyLicense
 */
package edu.gac.max.flexproducer;

import java.io.IOException;
import java.io.InputStreamReader;
import java.io.BufferedReader;
import javax.annotation.Resource;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.JMSContext;
import javax.jms.JMSRuntimeException;
import javax.jms.Queue;
import javax.jms.Topic;

/**
 * The FlexProducer class consists only of a main method, which sends
 * messages to a queue or topic, one per line of input.
 *
 * Run this program in conjunction with SynchConsumer or AsynchConsumer. Specify
 * "queue" or "topic" on the command line when you run the program. 
 */
public class FlexProducer {

    @Resource(lookup = "java:comp/DefaultJMSConnectionFactory")
    private static ConnectionFactory connectionFactory;
    @Resource(lookup = "jms/MyQueue")
    private static Queue queue;
    @Resource(lookup = "jms/MyTopic")
    private static Topic topic;

    /**
     * Main method.
     *
     * @param args the destination used by the example
     */
    public static void main(String[] args) {
        if (args.length != 1) {
            System.err.println(
                    "Program takes one or argument: "
                    + "<dest_type>");
            System.exit(1);
        }

        String destType = args[0];
        System.out.println("Destination type is " + destType);

        if (!(destType.equals("queue") || destType.equals("topic"))) {
            System.err.println("Argument must be \"queue\" or " + "\"topic\"");
            System.exit(1);
        }

        Destination dest;
	if (destType.equals("queue")) {
	    dest = queue;
	} else {
	    dest = topic;
	}

        /*
         * Within a try-with-resources block, create context
         *  and buffered input reader.
         * Send messages, one per input line.
         */
        try (JMSContext context = connectionFactory.createContext();
	     BufferedReader reader =
	     new BufferedReader(new InputStreamReader(System.in));) {

		while (true) {
                    String message = reader.readLine();
		    if(message == null)
			break;
		    context.createProducer().send(dest, message);
		}
	    } catch (JMSRuntimeException | IOException e) {
	    System.err.println("Exception occurred: " + e.toString());
	    System.exit(1);
	}
	System.exit(0);
    }
}
